@@ -7,8 +7,8 @@ use warnings;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.052'; # VERSION
-our $AUTHORITY = 'cpan:CHIM'; # AUTHORITY
+our $VERSION = '0.053'; # VERSION
+our $AUTHORITY = 'cpan:OLEG'; # AUTHORITY
 
 with 'Regru::API::Role::Client';
 
@@ -22,6 +22,7 @@ sub available_methods {[qw(
     add_aaaa
     add_caa
     add_cname
+    add_https
     add_mx
     add_ns
     add_txt
@@ -55,7 +56,7 @@ Regru::API::Zone - REG.API v2 DNS resource records management
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -157,6 +158,22 @@ error otherwise.
 
 More info at L<DNS management: add_cname|https://www.reg.com/support/help/api2#zone_add_cname>.
 
+=head2 add_https
+
+Creates a HTTPS (https connection rules) resource record for domain(s). Scope: B<clients>. Typical usage:
+
+    $resp = $client->zone->add_https(
+        subdomain  => '@',
+        priority   => 1,
+        target     => '.',
+        value      => 'alpn=h3,h2 port=8080'
+    );
+
+Answer will contains a field C<domains> with a list of results for each involved to this operation domain names or
+error otherwise.
+
+More info at L<DNS management: add_https|https://www.reg.com/support/help/api2#zone_add_https>.
+
 =head2 add_mx
 
 Creates a MX (mail exchange) resource record for domain(s). Scope: B<clients>. Typical usage:
@@ -293,7 +310,7 @@ Takes a set of actions and manipulates the resource records in batch mode. Scope
         ],
     );
 
-Action should one of allowed methods related to resource records: L</add_alias>, L</add_aaaa>, L</add_caa>, L</add_cname>, L</add_mx>,
+Action should one of allowed methods related to resource records: L</add_alias>, L</add_aaaa>, L</add_caa>, L</add_cname>, L</add_https>, L</add_mx>,
 L</add_ns>, L</add_txt>, L</add_srv> or L</remove_record>.
 
 Answer will contains a field C<domains> with a list of results for each involved to this operation domain names and actions or
